# Generated by Django 3.2.23 on 2023-12-14 21:01

import uuid

import django.db.models.deletion
from django.db import migrations, models

import authentic2.utils.evaluate
import authentic2.utils.template
from authentic2.apps.authenticators import get_default_min_password_strength


def create_login_password_authenticator(apps, schema_editor):
    LoginPasswordAuthenticator = apps.get_model('authenticators', 'LoginPasswordAuthenticator')
    LoginPasswordAuthenticator.objects.create(slug='password-authenticator', enabled=True)


class Migration(migrations.Migration):
    replaces = [
        ('authenticators', '0001_initial'),
        ('authenticators', '0002_loginpasswordauthenticator'),
        ('authenticators', '0003_auto_20220413_1504'),
        ('authenticators', '0004_auto_20220726_1708'),
        ('authenticators', '0005_addroleaction'),
        ('authenticators', '0006_loginpasswordauthenticator_registration_open'),
        ('authenticators', '0007_migrate_registration_open'),
        ('authenticators', '0008_new_password_settings_fields'),
        ('authenticators', '0009_migrate_new_password_settings'),
        ('authenticators', '0010_auto_20230614_1017'),
        ('authenticators', '0011_migrate_a2_accept_authentication_settings'),
        ('authenticators', '0012_loginpasswordauthenticator_min_password_strength'),
        ('authenticators', '0013_migrate_min_password_strength'),
        ('authenticators', '0014_auto_20230801_1517'),
        ('authenticators', '0015_alter_baseauthenticator_button_label'),
        ('authenticators', '0016_alter_addroleaction_condition'),
        ('authenticators', '0017_auto_20230927_1517'),
        ('authenticators', '0018_auto_20230927_1519'),
        ('authenticators', '0019_fix_addroleaction_condition'),
    ]

    initial = True

    dependencies = [
        ('a2_rbac', '0040_replace'),
        ('authentic2', '0051_replace'),
    ]

    operations = [
        migrations.CreateModel(
            name='BaseAuthenticator',
            fields=[
                (
                    'id',
                    models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
                ),
                ('uuid', models.CharField(default=uuid.uuid4, editable=False, max_length=255, unique=True)),
                ('name', models.CharField(blank=True, max_length=128, verbose_name='Name')),
                ('slug', models.SlugField(unique=True)),
                ('order', models.IntegerField(default=0, editable=False, verbose_name='Order')),
                ('enabled', models.BooleanField(default=False, editable=False)),
                (
                    'show_condition',
                    models.CharField(
                        blank=True,
                        default='',
                        help_text='Condition controlling authenticator display. For example, "\'backoffice\' in '
                        'login_hint or remote_addr == \'1.2.3.4\'" would hide the authenticator from normal users '
                        'except if they come from the specified IP address. Available variables include '
                        'service_ou_slug, service_slug, remote_addr, login_hint and headers.',
                        max_length=1024,
                        validators=[authentic2.utils.evaluate.condition_validator],
                        verbose_name='Show condition',
                    ),
                ),
                (
                    'button_description',
                    models.CharField(
                        blank=True,
                        help_text='Description will be shown at the top of login block (unless already set by theme).',
                        max_length=256,
                        verbose_name='Login block description',
                    ),
                ),
                (
                    'button_label',
                    models.CharField(default='Login', max_length=256, verbose_name='Login button label'),
                ),
                (
                    'ou',
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to='a2_rbac.organizationalunit',
                        verbose_name='organizational unit',
                    ),
                ),
            ],
            options={
                'ordering': ('-enabled', 'order', 'name', 'slug', 'ou'),
            },
        ),
        migrations.CreateModel(
            name='AddRoleAction',
            fields=[
                (
                    'id',
                    models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
                ),
                (
                    'mandatory',
                    models.BooleanField(default=False, editable=False, verbose_name='Mandatory (unused)'),
                ),
                (
                    'condition',
                    models.CharField(
                        blank=True,
                        default='',
                        help_text='Django condition controlling role attribution. For example, "\'Admin\' in attributes.groups" '
                        'will attribute the role if attributes has "groups" attribute containing the value "Admin". Variable "attributes" '
                        'contains the attributes received from the identity provider. If condition is not satisfied the role will be removed.',
                        max_length=1024,
                        validators=[authentic2.utils.template.validate_condition_template],
                        verbose_name='Condition',
                    ),
                ),
                (
                    'authenticator',
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='add_role_actions',
                        to='authenticators.baseauthenticator',
                    ),
                ),
                (
                    'role',
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='add_role_actions',
                        to='a2_rbac.role',
                        verbose_name='Role',
                    ),
                ),
            ],
            options={
                'verbose_name': 'Add a role',
                'verbose_name_plural': 'Add roles',
                'default_related_name': 'add_role_actions',
            },
        ),
        migrations.CreateModel(
            name='LoginPasswordAuthenticator',
            fields=[
                (
                    'baseauthenticator_ptr',
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to='authenticators.baseauthenticator',
                    ),
                ),
                (
                    'registration_open',
                    models.BooleanField(
                        default=True,
                        help_text='Allow users to create accounts.',
                        verbose_name='Registration open',
                    ),
                ),
                (
                    'remember_me',
                    models.PositiveIntegerField(
                        blank=True,
                        help_text='Session duration as seconds when using the remember me checkbox. Leave blank to hide the checkbox.',
                        null=True,
                        verbose_name='Remember me duration',
                    ),
                ),
                (
                    'include_ou_selector',
                    models.BooleanField(default=False, verbose_name='Include OU selector in login form'),
                ),
                (
                    'accept_email_authentication',
                    models.BooleanField(
                        default=True, verbose_name='Let the users identify with their email address'
                    ),
                ),
                (
                    'accept_phone_authentication',
                    models.BooleanField(
                        default=False, verbose_name='Let the users identify with their phone number'
                    ),
                ),
                (
                    'min_password_strength',
                    models.IntegerField(
                        blank=True,
                        choices=[
                            (None, 'Follow static checks'),
                            (0, 'Very Weak'),
                            (1, 'Weak'),
                            (2, 'Fair'),
                            (3, 'Good'),
                            (4, 'Strong'),
                        ],
                        default=get_default_min_password_strength,
                        help_text='Password strength, using dynamic indicators such as common names, dates and other popular patterns. Selecting '
                        '"static checks" will instead validate that a password contains enough different kind of caracters. Password indicator on '
                        'registration form will reflect the chosen policy.',
                        null=True,
                        verbose_name='Minimum password strength',
                    ),
                ),
                (
                    'password_min_length',
                    models.PositiveIntegerField(default=8, null=True, verbose_name='Password minimum length'),
                ),
                (
                    'password_regex',
                    models.CharField(
                        blank=True,
                        default='',
                        max_length=512,
                        verbose_name='Regular expression for validating passwords',
                    ),
                ),
                (
                    'password_regex_error_msg',
                    models.CharField(
                        blank=True,
                        default='',
                        max_length=1024,
                        verbose_name='Error message to show when the password do not validate the regular expression',
                    ),
                ),
                (
                    'login_exponential_retry_timeout_duration',
                    models.FloatField(
                        default=1,
                        help_text='Exponential backoff base factor duration as seconds until next try after a login failure.',
                        verbose_name='Retry timeout duration',
                    ),
                ),
                (
                    'login_exponential_retry_timeout_factor',
                    models.FloatField(
                        default=1.8,
                        help_text='Exponential backoff factor duration as seconds until next try after a login failure.',
                        verbose_name='Retry timeout factor',
                    ),
                ),
                (
                    'login_exponential_retry_timeout_max_duration',
                    models.PositiveIntegerField(
                        default=3600,
                        help_text='Maximum exponential backoff maximum duration as seconds until next try after a login failure.',
                        verbose_name='Retry timeout max duration',
                    ),
                ),
                (
                    'login_exponential_retry_timeout_min_duration',
                    models.PositiveIntegerField(
                        default=10,
                        help_text='Minimum exponential backoff maximum duration as seconds until next try after a login failure.',
                        verbose_name='Retry timeout min duration',
                    ),
                ),
                (
                    'emails_ip_ratelimit',
                    models.CharField(
                        default='10/h',
                        help_text='Maximum rate of email sendings triggered by the same IP address.',
                        max_length=32,
                        verbose_name='Emails IP ratelimit',
                    ),
                ),
                (
                    'sms_ip_ratelimit',
                    models.CharField(
                        default='10/h',
                        help_text='Maximum rate of SMSs triggered by the same IP address.',
                        max_length=32,
                        verbose_name='SMS IP ratelimit',
                    ),
                ),
                (
                    'emails_address_ratelimit',
                    models.CharField(
                        default='3/d',
                        help_text='Maximum rate of emails sent to the same email address.',
                        max_length=32,
                        verbose_name='Emails address ratelimit',
                    ),
                ),
                (
                    'sms_number_ratelimit',
                    models.CharField(
                        default='10/h',
                        help_text='Maximum rate of SMSs sent to the same phone number.',
                        max_length=32,
                        verbose_name='SMS number ratelimit',
                    ),
                ),
                (
                    'phone_identifier_field',
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to='authentic2.attribute',
                        verbose_name='Phone field used as user identifier',
                    ),
                ),
            ],
            options={
                'verbose_name': 'Password',
            },
            bases=('authenticators.baseauthenticator',),
        ),
        migrations.RunPython(create_login_password_authenticator, reverse_code=migrations.RunPython.noop),
    ]
