import django.utils.timezone
from django.db import migrations, models

import authentic2.utils.misc
import authentic2.validators


class Migration(migrations.Migration):
    dependencies = [
        ('auth', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                (
                    'id',
                    models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True),
                ),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                (
                    'last_login',
                    models.DateTimeField(default=django.utils.timezone.now, verbose_name='last login'),
                ),
                (
                    'is_superuser',
                    models.BooleanField(
                        default=False,
                        help_text=(
                            'Designates that this user has all permissions without explicitly assigning them.'
                        ),
                        verbose_name='superuser status',
                    ),
                ),
                (
                    'uuid',
                    models.CharField(
                        default=authentic2.utils.misc.get_hex_uuid,
                        verbose_name='uuid',
                        unique=True,
                        max_length=32,
                        editable=False,
                    ),
                ),
                (
                    'username',
                    models.CharField(max_length=256, null=True, verbose_name='username', blank=True),
                ),
                ('first_name', models.CharField(max_length=64, verbose_name='first name', blank=True)),
                ('last_name', models.CharField(max_length=64, verbose_name='last name', blank=True)),
                (
                    'email',
                    models.EmailField(
                        blank=True,
                        max_length=254,
                        verbose_name='email address',
                        validators=[authentic2.validators.EmailValidator],
                    ),
                ),
                (
                    'is_staff',
                    models.BooleanField(
                        default=False,
                        help_text='Designates whether the user can log into this admin site.',
                        verbose_name='staff status',
                    ),
                ),
                (
                    'is_active',
                    models.BooleanField(
                        default=True,
                        help_text=(
                            'Designates whether this user should be treated as active. Unselect this instead'
                            ' of deleting accounts.'
                        ),
                        verbose_name='active',
                    ),
                ),
                (
                    'date_joined',
                    models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined'),
                ),
                (
                    'groups',
                    models.ManyToManyField(
                        related_query_name='user',
                        related_name='user_set',
                        to='auth.Group',
                        blank=True,
                        help_text=(
                            'The groups this user belongs to. A user will get all permissions granted to each'
                            ' of his/her group.'
                        ),
                        verbose_name='groups',
                    ),
                ),
                (
                    'user_permissions',
                    models.ManyToManyField(
                        related_query_name='user',
                        related_name='user_set',
                        to='auth.Permission',
                        blank=True,
                        help_text='Specific permissions for this user.',
                        verbose_name='user permissions',
                    ),
                ),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
            bases=(models.Model,),
        ),
    ]
