# Generated by Django 3.2.23 on 2023-12-14 21:01

import django.contrib.postgres.indexes
import django.db.models.deletion
from django.db import migrations, models

import authentic2.a2_rbac.utils


def create_trigger(apps, schema_editor):
    with schema_editor.connection.cursor() as cursor:
        cursor.execute('SHOW default_text_search_config')
        assert cursor.fetchone()
        cursor.execute(
            '''CREATE OR REPLACE FUNCTION authentic2_update_atv_search_vector() RETURNS TRIGGER AS $$
BEGIN
    IF TG_OP = 'INSERT' OR (TG_OP = 'UPDATE' AND NEW.content <> OLD.content) THEN
        NEW.search_vector = to_tsvector(NEW.content);
    END IF;
    RETURN NEW;
END; $$ LANGUAGE plpgsql'''
        )
        cursor.execute(
            '''CREATE TRIGGER authentic2_attributevalue_search_vector_trigger
BEFORE INSERT OR UPDATE OF content
ON authentic2_attributevalue
FOR EACH ROW EXECUTE PROCEDURE authentic2_update_atv_search_vector()'''
        )


def drop_trigger(apps, schema_editor):
    with schema_editor.connection.cursor() as cursor:
        cursor.execute(
            'DROP TRIGGER IF EXISTS authentic2_attributevalue_search_vector_trigger ON'
            ' authentic2_attributevalue'
        )
        cursor.execute('DROP FUNCTION IF EXISTS authentic2_update_atv_search_vector')


def initialize_services_runtime_settings(apps, schema_editor):
    from authentic2.utils.misc import RUNTIME_SETTINGS

    Setting = apps.get_model('authentic2', 'Setting')
    for key, data in RUNTIME_SETTINGS.items():
        Setting.objects.get_or_create(
            key=key,
            defaults={
                'value': data['value'],
            },
        )


class Migration(migrations.Migration):
    replaces = [
        ('authentic2', '0001_initial'),
        ('authentic2', '0002_auto_20150320_1418'),
        ('authentic2', '0003_auto_20150409_1840'),
        ('authentic2', '0004_service'),
        ('authentic2', '0005_service_ou'),
        ('authentic2', '0006_conditional_slug_index'),
        ('authentic2', '0007_auto_20150523_0028'),
        ('authentic2', '0008_auto_20160204_1415'),
        ('authentic2', '0009_auto_20160211_2247'),
        ('authentic2', '0010_attributevalue_multiple'),
        ('authentic2', '0011_auto_20160211_2253'),
        ('authentic2', '0012_auto_20160211_2255'),
        ('authentic2', '0013_auto_20160211_2258'),
        ('authentic2', '0014_attributevalue_verified'),
        ('authentic2', '0015_auto_20160621_1711'),
        ('authentic2', '0016_attribute_disabled'),
        ('authentic2', '0017_modify_attribute_serialization'),
        ('authentic2', '0018_auto_20170524_0842'),
        ('authentic2', '0019_auto_20170309_1529'),
        ('authentic2', '0020_delete_federatedid'),
        ('authentic2', '0021_attribute_order'),
        ('authentic2', '0022_attribute_scopes'),
        ('authentic2', '0023_auto_20181031_0900'),
        ('authentic2', '0024_auto_20190617_1113'),
        ('authentic2', '0025_auto_20191009_1047'),
        ('authentic2', '0026_token'),
        ('authentic2', '0027_remove_deleteduser'),
        ('authentic2', '0028_trigram_unaccent_index'),
        ('authentic2', '0029_auto_20201013_1614'),
        ('authentic2', '0030_clean_admin_tools_tables'),
        ('authentic2', '0031_add_search_vector_to_attributes'),
        ('authentic2', '0032_initialize_search_vectors'),
        ('authentic2', '0033_recreate_immutable_unaccent'),
        ('authentic2', '0034_attribute_required_on_login'),
        ('authentic2', '0035_service_home_url'),
        ('authentic2', '0036_service_profile_types'),
        ('authentic2', '0037_auto_20220331_1513'),
        ('authentic2', '0038_make_service_ou_non_null'),
        ('authentic2', '0039_add_unique_attribute_constraint'),
        ('authentic2', '0040_add_external_guid'),
        ('authentic2', '0041_lock'),
        ('authentic2', '0042_api_client'),
        ('authentic2', '0043_api_client_description'),
        ('authentic2', '0044_apiclient_ou'),
        ('authentic2', '0044_auto_20220530_1426'),
        ('authentic2', '0045_auto_20221222_1013'),
        ('authentic2', '0045_auto_20230117_1513'),
        ('authentic2', '0045_smscode'),
        ('authentic2', '0046_runtimesetting'),
        ('authentic2', '0047_initialize_services_runtime_settings'),
        ('authentic2', '0048_rename_services_runtime_settings'),
        ('authentic2', '0049_apiclient_allowed_user_attributes'),
        ('authentic2', '0050_initialize_users_advanced_configuration'),
    ]

    initial = True

    dependencies = [
        ('a2_rbac', '0041_replace'),
        ('custom_user', '0037_replace'),
        ('contenttypes', '0002_remove_content_type_name'),
        ('authentic2', '0051_replace'),
    ]

    operations = [
        migrations.CreateModel(
            name='LDAPUser',
            fields=[],
            options={
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('custom_user.user',),
        ),
        migrations.AddField(
            model_name='userexternalid',
            name='user',
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to='custom_user.user', verbose_name='user'
            ),
        ),
        migrations.AddField(
            model_name='smscode',
            name='user',
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to='custom_user.user',
                verbose_name='user',
            ),
        ),
        migrations.AddField(
            model_name='service',
            name='authorized_roles',
            field=models.ManyToManyField(
                blank=True,
                related_name='allowed_services',
                through='authentic2.AuthorizedRole',
                to='a2_rbac.Role',
                verbose_name='authorized services',
            ),
        ),
        migrations.AddField(
            model_name='service',
            name='ou',
            field=models.ForeignKey(
                default=authentic2.a2_rbac.utils.get_default_ou_pk,
                on_delete=django.db.models.deletion.CASCADE,
                to='a2_rbac.organizationalunit',
                verbose_name='organizational unit',
            ),
        ),
        migrations.AddField(
            model_name='service',
            name='profile_types',
            field=models.ManyToManyField(
                blank=True,
                related_name='_authentic2_service_profile_types_+',
                through='custom_user.ServiceProfileType',
                to='custom_user.ProfileType',
                verbose_name='allowed services for this profile type',
            ),
        ),
        migrations.AddField(
            model_name='passwordreset',
            name='user',
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.CASCADE, to='custom_user.user', verbose_name='user'
            ),
        ),
        migrations.AddField(
            model_name='logouturl',
            name='content_type',
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to='contenttypes.contenttype',
                verbose_name='content type',
            ),
        ),
        migrations.AddField(
            model_name='authorizedrole',
            name='role',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='a2_rbac.role'),
        ),
        migrations.AddField(
            model_name='authorizedrole',
            name='service',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='authentic2.service'),
        ),
        migrations.AddField(
            model_name='attributevalue',
            name='attribute',
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to='authentic2.attribute',
                verbose_name='attribute',
            ),
        ),
        migrations.AddField(
            model_name='attributevalue',
            name='content_type',
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to='contenttypes.contenttype',
                verbose_name='content type',
            ),
        ),
        migrations.AddField(
            model_name='apiclient',
            name='allowed_user_attributes',
            field=models.ManyToManyField(
                blank=True,
                related_name='apiclients',
                to='authentic2.Attribute',
                verbose_name='allowed user attributes',
            ),
        ),
        migrations.AddField(
            model_name='apiclient',
            name='apiclient_roles',
            field=models.ManyToManyField(
                blank=True, related_name='apiclients', to='a2_rbac.Role', verbose_name='roles'
            ),
        ),
        migrations.AddField(
            model_name='apiclient',
            name='ou',
            field=models.ForeignKey(
                blank=True,
                default=authentic2.a2_rbac.utils.get_default_ou_pk,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to='a2_rbac.organizationalunit',
                verbose_name='organizational unit',
            ),
        ),
        migrations.AddConstraint(
            model_name='userexternalid',
            constraint=models.CheckConstraint(
                check=models.Q(
                    ('external_id__isnull', False), ('external_guid__isnull', False), _connector='OR'
                ),
                name='at_least_one_id',
            ),
        ),
        migrations.AlterUniqueTogether(
            name='userexternalid',
            unique_together={('source', 'external_id'), ('source', 'external_guid')},
        ),
        migrations.AlterUniqueTogether(
            name='service',
            unique_together={('slug', 'ou')},
        ),
        migrations.AddIndex(
            model_name='attributevalue',
            index=django.contrib.postgres.indexes.GinIndex(
                fields=['search_vector'], name='authentic2_atv_tsvector_idx'
            ),
        ),
        migrations.AddConstraint(
            model_name='attributevalue',
            constraint=models.UniqueConstraint(
                condition=models.Q(('multiple', False)),
                fields=('content_type', 'object_id', 'attribute'),
                name='unique_attribute_idx',
            ),
        ),
        migrations.AlterUniqueTogether(
            name='attributevalue',
            unique_together={('content_type', 'object_id', 'attribute', 'multiple', 'content')},
        ),
        migrations.RunPython(create_trigger, drop_trigger),
        migrations.RunPython(
            initialize_services_runtime_settings,
            reverse_code=migrations.RunPython.noop,
        ),
    ]
